@@ -7,20 +7,16 @@ import unittest
 import warnings
 
 import django
+from captcha.conf import settings
+from captcha.fields import CaptchaField, CaptchaTextInput
+from captcha.models import CaptchaStore
 from django.core import management
 from django.core.exceptions import ImproperlyConfigured
 from django.test import TestCase, override_settings
 from django.utils import timezone
-
-import six
-from captcha.conf import settings
-from captcha.fields import CaptchaField, CaptchaTextInput
-from captcha.models import CaptchaStore
 from PIL import Image
-from six import text_type, u
 from testfixtures import LogCapture
 
-
 if django.VERSION < (1, 10):  # NOQA
     from django.core.urlresolvers import reverse  # NOQA
 else:  # NOQA
@@ -79,7 +75,7 @@ class CaptchaCase(TestCase):
         return hash_, response
 
     def test_image(self):
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
             self.assertTrue(response.has_header("content-type"))
@@ -193,7 +189,7 @@ class CaptchaCase(TestCase):
         try:
             CaptchaStore.objects.get(hashkey=hash_)
             self.fail()
-        except:
+        except Exception:
             pass
 
     def test_custom_error_message(self):
@@ -242,7 +238,7 @@ class CaptchaCase(TestCase):
             try:
                 store_1 = CaptchaStore.objects.get(hashkey=hash_1)
                 store_2 = CaptchaStore.objects.get(hashkey=hash_2)
-            except:
+            except Exception:
                 self.fail()
 
             self.assertTrue(store_1.pk != store_2.pk)
@@ -263,7 +259,7 @@ class CaptchaCase(TestCase):
 
             try:
                 store_2 = CaptchaStore.objects.get(hashkey=hash_2)
-            except:
+            except Exception:
                 self.fail()
 
             r2 = self.client.post(
@@ -281,7 +277,7 @@ class CaptchaCase(TestCase):
 
     def test_output_format(self):
         for urlname in ("captcha-test", "captcha-test-model-form"):
-            settings.CAPTCHA_OUTPUT_FORMAT = u(
+            settings.CAPTCHA_OUTPUT_FORMAT = (
                 "%(image)s<p>Hello, captcha world</p>%(hidden_field)s%(text_field)s"
             )
             r = self.client.get(reverse(urlname))
@@ -290,7 +286,7 @@ class CaptchaCase(TestCase):
 
     def test_invalid_output_format(self):
         for urlname in ("captcha-test", "captcha-test-model-form"):
-            settings.CAPTCHA_OUTPUT_FORMAT = u("%(image)s")
+            settings.CAPTCHA_OUTPUT_FORMAT = "%(image)s"
             try:
                 with warnings.catch_warnings(record=True) as w:
                     self.client.get(reverse(urlname))
@@ -302,7 +298,7 @@ class CaptchaCase(TestCase):
                 self.assertTrue("CAPTCHA_OUTPUT_FORMAT" in str(e))
 
     def test_per_form_format(self):
-        settings.CAPTCHA_OUTPUT_FORMAT = u(
+        settings.CAPTCHA_OUTPUT_FORMAT = (
             "%(image)s testCustomFormatString %(hidden_field)s %(text_field)s"
         )
         r = self.client.get(reverse("captcha-test"))
@@ -316,7 +312,7 @@ class CaptchaCase(TestCase):
         self.assertEqual(response, u"111111")
 
     def test_issue31_proper_abel(self):
-        settings.CAPTCHA_OUTPUT_FORMAT = u("%(image)s %(hidden_field)s %(text_field)s")
+        settings.CAPTCHA_OUTPUT_FORMAT = "%(image)s %(hidden_field)s %(text_field)s"
         r = self.client.get(reverse("captcha-test"))
         self.assertTrue('<label for="id_captcha_1"' in str(r.content))
 
@@ -325,14 +321,14 @@ class CaptchaCase(TestCase):
             reverse("captcha-refresh"), HTTP_X_REQUESTED_WITH="XMLHttpRequest"
         )
         try:
-            new_data = json.loads(six.text_type(r.content, encoding="ascii"))
+            new_data = json.loads(str(r.content, encoding="ascii"))
             self.assertTrue("image_url" in new_data)
             self.assertTrue("audio_url" in new_data)
-        except:
+        except Exception:
             self.fail()
 
     def test_content_length(self):
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertTrue(response.has_header("content-length"))
             self.assertTrue(response["content-length"].isdigit())
@@ -343,7 +339,7 @@ class CaptchaCase(TestCase):
         This test covers a default django field and widget behavior
         It not assert anything. If something is wrong it will raise a error!
         """
-        settings.CAPTCHA_OUTPUT_FORMAT = u("%(image)s %(hidden_field)s %(text_field)s")
+        settings.CAPTCHA_OUTPUT_FORMAT = "%(image)s %(hidden_field)s %(text_field)s"
         widget = CaptchaTextInput(attrs={"class": "required"})
         CaptchaField(widget=widget)
 
@@ -449,17 +445,17 @@ class CaptchaCase(TestCase):
         r = self.client.get(reverse("captcha-test"))
         self.assertFalse(
             'autocapitalize="off" autocomplete="off" autocorrect="off" spellcheck="false" type="hidden" name="captcha_0"'
-            in six.text_type(r.content)
+            in str(r.content)
         )
         self.assertFalse(
             'autocapitalize="off" autocomplete="off" autocorrect="off" spellcheck="false" id="id_captcha_0" name="captcha_0" type="hidden"'
-            in six.text_type(r.content)
+            in str(r.content)
         )
 
     def test_transparent_background(self):
         __current_test_mode_setting = settings.CAPTCHA_BACKGROUND_COLOR
         settings.CAPTCHA_BACKGROUND_COLOR = "transparent"
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
             self.assertTrue(response.has_header("content-type"))
@@ -468,7 +464,7 @@ class CaptchaCase(TestCase):
         settings.CAPTCHA_BACKGROUND_COLOR = __current_test_mode_setting
 
     def test_expired_captcha_returns_410(self):
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
             CaptchaStore.objects.filter(hashkey=key).delete()
@@ -478,19 +474,17 @@ class CaptchaCase(TestCase):
     def test_id_prefix(self):
         r = self.client.get(reverse("captcha-test-id-prefix"))
         self.assertTrue(
-            '<label for="form1_id_captcha1_1">Captcha1:</label>'
-            in six.text_type(r.content)
+            '<label for="form1_id_captcha1_1">Captcha1:</label>' in str(r.content)
         )
-        self.assertTrue('id="form1_id_captcha1_1"' in six.text_type(r.content))
+        self.assertTrue('id="form1_id_captcha1_1"' in str(r.content))
         self.assertTrue(
-            '<label for="form2_id_captcha2_1">Captcha2:</label>'
-            in six.text_type(r.content)
+            '<label for="form2_id_captcha2_1">Captcha2:</label>' in str(r.content)
         )
-        self.assertTrue('id="form2_id_captcha2_1"' in six.text_type(r.content))
+        self.assertTrue('id="form2_id_captcha2_1"' in str(r.content))
 
     def test_image_size(self):
         __current_test_mode_setting = settings.CAPTCHA_IMAGE_SIZE
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             settings.CAPTCHA_IMAGE_SIZE = (201, 97)
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
@@ -505,19 +499,19 @@ class CaptchaCase(TestCase):
         __current_test_mode_setting = settings.CAPTCHA_FONT_PATH
         settings.CAPTCHA_FONT_PATH = vera
 
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
             self.assertEqual(response["content-type"], "image/png")
 
         settings.CAPTCHA_FONT_PATH = [vera, vera, vera]
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
             self.assertEqual(response.status_code, 200)
             self.assertEqual(response["content-type"], "image/png")
 
         settings.CAPTCHA_FONT_PATH = False
-        for key in [store.hashkey for store in six.itervalues(self.stores)]:
+        for key in [store.hashkey for store in self.stores.values()]:
             try:
                 response = self.client.get(reverse("captcha-image", kwargs=dict(key=key)))
                 self.fail()
@@ -535,7 +529,7 @@ class CaptchaCase(TestCase):
         for urlname in ("captcha-test", "captcha-test-model-form"):
             settings.CAPTCHA_CHALLENGE_FUNCT = "captcha.tests.trivial_challenge"
             r = self.client.get(reverse(urlname))
-            self.assertTrue("captcha-template-test" in six.text_type(r.content))
+            self.assertTrue("captcha-template-test" in str(r.content))
         settings.CAPTCHA_IMAGE_TEMPLATE = __current_test_mode_setting
         settings.CAPTCHA_FIELD_TEMPLATE = __current_field_template
 
@@ -550,7 +544,7 @@ class CaptchaCase(TestCase):
 
         self.assertEqual(
             response,
-            text_type(
+            str(
                 eval(
                     challenge.replace(settings.CAPTCHA_MATH_CHALLENGE_OPERATOR, "*")[:-1]
                 )
@@ -592,9 +586,9 @@ class CaptchaCase(TestCase):
         __current_test_get_from_pool_setting = settings.CAPTCHA_GET_FROM_POOL
         settings.CAPTCHA_GET_FROM_POOL = True
         CaptchaStore.objects.all().delete()  # Delete objects created during SetUp
-        with LogCapture() as l:
+        with LogCapture() as log:
             CaptchaStore.pick()
-        l.check(
+        log.check(
             ("captcha.models", "ERROR", "Couldn't get a captcha from pool, generating")
         )
         self.assertEqual(CaptchaStore.objects.count(), 1)
